<?php

namespace Litecms\CouponSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\CouponSetting\Http\Requests\CouponsettingRequest;
use Litecms\CouponSetting\Interfaces\CouponsettingRepositoryInterface;
use Litecms\CouponSetting\Models\Couponsetting;

/**
 * Resource controller class for couponsetting.
 */
class CouponsettingResourceController extends BaseController
{

    /**
     * Initialize couponsetting resource controller.
     *
     * @param type CouponsettingRepositoryInterface $couponsetting
     *
     * @return null
     */
    public function __construct(CouponsettingRepositoryInterface $couponsetting)
    {
        parent::__construct();
        $this->repository = $couponsetting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\CouponSetting\Repositories\Criteria\CouponsettingResourceCriteria::class);
    }

    /**
     * Display a list of couponsetting.
     *
     * @return Response
     */
    public function index(CouponsettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\CouponSetting\Repositories\Presenter\CouponsettingPresenter::class)
                ->$function();
        }

        $couponsettings = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('coupon__setting::couponsetting.names'))
            ->view('coupon__setting::couponsetting.index', true)
            ->data(compact('couponsettings', 'view'))
            ->output();
    }

    /**
     * Display couponsetting.
     *
     * @param Request $request
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function show(CouponsettingRequest $request, Couponsetting $couponsetting)
    {

        if ($couponsetting->exists) {
            $view = 'coupon__setting::couponsetting.show';
        } else {
            $view = 'coupon__setting::couponsetting.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('coupon__setting::couponsetting.name'))
            ->data(compact('couponsetting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new couponsetting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CouponsettingRequest $request)
    {

        $couponsetting = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('coupon__setting::couponsetting.name')) 
            ->view('coupon__setting::couponsetting.create', true) 
            ->data(compact('couponsetting'))
            ->output();
    }

    /**
     * Create new couponsetting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CouponsettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $couponsetting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('coupon__setting::couponsetting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('coupon__setting/couponsetting/' . $couponsetting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/coupon__setting/couponsetting'))
                ->redirect();
        }

    }

    /**
     * Show couponsetting for editing.
     *
     * @param Request $request
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function edit(CouponsettingRequest $request, Couponsetting $couponsetting)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('coupon__setting::couponsetting.name'))
            ->view('coupon__setting::couponsetting.edit', true)
            ->data(compact('couponsetting'))
            ->output();
    }

    /**
     * Update the couponsetting.
     *
     * @param Request $request
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function update(CouponsettingRequest $request, Couponsetting $couponsetting)
    {
        try {
            $attributes = $request->all();

            $couponsetting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('coupon__setting::couponsetting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('coupon__setting/couponsetting/' . $couponsetting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon__setting/couponsetting/' . $couponsetting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the couponsetting.
     *
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function destroy(CouponsettingRequest $request, Couponsetting $couponsetting)
    {
        try {

            $couponsetting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('coupon__setting::couponsetting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('coupon__setting/couponsetting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon__setting/couponsetting/' . $couponsetting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple couponsetting.
     *
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function delete(CouponsettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('coupon__setting::couponsetting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('coupon__setting/couponsetting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/coupon__setting/couponsetting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted couponsettings.
     *
     * @param Model   $couponsetting
     *
     * @return Response
     */
    public function restore(CouponsettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('coupon__setting::couponsetting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/coupon__setting/couponsetting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/coupon__setting/couponsetting/'))
                ->redirect();
        }

    }

}
